<?php

namespace Drupal\ocr_image\Plugin\Field\FieldWidget;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\file\Entity\File;
use Drupal\image\Plugin\Field\FieldWidget\ImageWidget;
use Drupal\ocr_image\Plugin\Field\TesseractLanguages;
use thiagoalessio\TesseractOCR\TesseractOCR;
use Symfony\Polyfill\Intl\Normalizer\Normalizer;

/**
 * Plugin implementation of the 'Ocr image' widget.
 *
 * @FieldWidget(
 *   id = "ocr_image",
 *   label = @Translation("Ocr image"),
 *   field_types = {
 *     "image"
 *   }
 * )
 */
class OcrImageWidget extends ImageWidget {

  use Base;

  /**
   * {@inheritDoc}
   */
  public function formElement(FieldItemListInterface $items, $delta, array $element, array &$form, FormStateInterface $form_state) {
    $element = parent::formElement($items, $delta, $element, $form, $form_state);
    $field_name = $items->getName();
    if (!empty($field_text_name = $this->getSetting('text_field'))) {
      $language = $this->getSetting('language');
      $fid = $form_state->getValue($field_name);
      if (!empty($fid)) {
        if (is_array($fid)) {
          $fid = end($fid);
          if (is_array($fid) && !empty($fid["fids"])) {
            $fid = end($fid["fids"]);
          }
        }
        $file = File::load($fid);
        $uri = $file->getFileUri();
        $stream_wrapper_manager = \Drupal::service('stream_wrapper_manager')
          ->getViaUri($uri);
        $file_path = $stream_wrapper_manager->realpath();
        if (empty($language)) {
          $language = TesseractLanguages::tesseractConvertLang();
        }
        $line_datas = $this->getLinesText($file_path, $language, $this->getSetting('limit'));
        if (!empty($line_datas)) {
          $ocr = implode(PHP_EOL, $line_datas);
          $form_state->setValue($field_text_name, $ocr);
          $alt = trim(strip_tags(array_shift($line_datas)));
          $element["#default_value"]["alt"] = substr($alt, 0, 512);
          $title = trim(strip_tags(implode(PHP_EOL, $line_datas)));
          $element["#default_value"]["title"] = substr($title, 0, 1024);
          $element['#attached']['drupalSettings']['ocr_field_widget'] = [
            'field_name' => $field_name,
            'field' => $field_text_name,
            'ocr' => $ocr,
          ];
          $element['#attached']['library'][] = 'ocr_image/ocr_image';
        }
      }
    }

    return $element;
  }

  /**
   * Returns string from image.
   *
   * @param string $image
   *   The directory image.
   * @param string $lang
   *   Language to ocr.
   * @param int $limit
   *   Limited characters.
   * @param int $dpi
   *   Dpi.
   *
   * @return array
   *   The array string line text.
   */
  public function getLinesText($image, $lang = 'eng', $limit = 0, $dpi = 300) {
    $ocr = new TesseractOCR($image);
    $data = '';
    try {
      $data = $ocr->lang($lang)->dpi($dpi)->run();
    }
    catch (\Exception $e) {
      $this->messenger()->addError($this->t("TesseractOCR not found"));
    }
    $data = Normalizer::normalize(trim($data), Normalizer::FORM_C);
    if (!empty($limit) && !empty($data)) {
      $data = substr($data, 0, $limit);
    }
    $line_datas = array_filter(explode("\n", $data), function ($value) {
      return !empty(trim($value));
    });

    return $line_datas;
  }

}
