<?php

namespace Drupal\ocr_image\Plugin\Field;

/**
 * Class trait all languages for tesseract.
 */
class TesseractLanguages {

  /**
   * Convert drupal language iso to tesseract lang.
   *
   * @return string
   *   Return code language tesseract.
   */
  public static function tesseractConvertLang() {
    $languages = [
      'aa' => 'afr',
      'am' => 'amh',
      'ar' => 'ara',
      'as' => 'asm',
      'az' => 'aze',
      'be' => 'bel',
      'bn' => 'ben',
      'bo' => 'bod',
      'bs' => 'bos',
      'br' => 'bre',
      'bg' => 'bul',
      'ca' => 'cat',
      'cs' => 'ces',
      'zh-hans' => 'chi_sim',
      'zh-hant' => 'chi_tra',
      'co' => 'cos',
      'cy' => 'cym',
      'da' => 'dan',
      'de' => 'deu',
      'dz' => 'dzo',
      'el' => 'ell',
      'en' => 'eng',
      'en-gb' => 'enm',
      'eo' => 'epo',
      'et' => 'est',
      'eu' => 'eus',
      'fo' => 'fao',
      'fa' => 'fas',
      'fi' => 'fin',
      'fr' => 'fra',
      'fy' => 'fry',
      'gd' => 'gla',
      'ga' => 'gle',
      'gl' => 'glg',
      'gu' => 'guj',
      'ht' => 'hat',
      'he' => 'heb',
      'hi' => 'hin',
      'hr' => 'hrv',
      'hu' => 'hun',
      'hy' => 'hye',
      'iu' => 'iku',
      'id' => 'ind',
      'is' => 'isl',
      'it' => 'ita',
      'jv' => 'jav',
      'ja' => 'jpn',
      'kn' => 'kan',
      'ka' => 'kat',
      'kk' => 'kaz',
      'km' => 'khm',
      'ky' => 'kir',
      'ko' => 'kor',
      'ku' => 'kur',
      'lo' => 'lao',
      'la' => 'lat',
      'lv' => 'lav',
      'lt' => 'lit',
      'ml' => 'mal',
      'mr' => 'mar',
      'mk' => 'mkd',
      'mt' => 'mlt',
      'mn' => 'mon',
      'ms' => 'msa',
      'my' => 'mya',
      'ne' => 'nep',
      'no' => 'nor',
      'oc' => 'oci',
      'or' => 'ori',
      'pa' => 'pan',
      'pl' => 'pol',
      'pt' => 'por',
      'ps' => 'pus',
      'qu' => 'que',
      'ro' => 'ron',
      'ru' => 'rus',
      'sa' => 'san',
      'si' => 'sin',
      'sk' => 'slk',
      'sl' => 'slv',
      'es' => 'spa',
      'sq' => 'sqi',
      'sr' => 'srp',
      'su' => 'sun',
      'sw' => 'swa',
      'sv' => 'swe',
      'sy' => 'syr',
      'ta' => 'tam',
      'te' => 'tel',
      'tg' => 'tgk',
      'tl' => 'tgl',
      'th' => 'tha',
      'ti' => 'tir',
      'to' => 'ton',
      'tr' => 'tur',
      'ug' => 'uig',
      'uk' => 'ukr',
      'ur' => 'urd',
      'uz' => 'uzb',
      'vi' => 'vie',
      'yi' => 'yid',
      'yo' => 'yor',
    ];
    $isoLang = \Drupal::languageManager()->getCurrentLanguage()->getId();
    return $languages[$isoLang] ?? 'eng';
  }

  /**
   * Option languages for Tesseract.
   */
  public static function tesseractLangues() {
    return [
      'afr' => t('Afrikaans'),
      'amh' => t('Amharic'),
      'ara' => t('Arabic'),
      'asm' => t('Assamese'),
      'aze' => t('Azerbaijani'),
      'aze_cyrl' => t('Azerbaijani - Cyrilic'),
      'bel' => t('Belarusian'),
      'ben' => t('Bengali'),
      'bod' => t('Tibetan'),
      'bos' => t('Bosnian'),
      'bre' => t('Breton'),
      'bul' => t('Bulgarian'),
      'cat' => t('Catalan; Valencian'),
      'ceb' => t('Cebuano'),
      'ces' => t('Czech'),
      'chi_sim' => t('Chinese - Simplified'),
      'chi_tra' => t('Chinese - Traditional'),
      'chr' => t('Cherokee'),
      'cos' => t('Corsican'),
      'cym' => t('Welsh'),
      'dan' => t('Danish'),
      'dan_frak' => t('Danish - Fraktur (contrib)'),
      'deu' => t('German'),
      'deu_frak' => t('German - Fraktur (contrib)'),
      'dzo' => t('Dzongkha'),
      'ell' => t('Greek, Modern (1453-)'),
      'eng' => t('English'),
      'enm' => t('English, Middle (1100-1500)'),
      'epo' => t('Esperanto'),
      'equ' => t('Math / equation detection module'),
      'est' => t('Estonian'),
      'eus' => t('Basque'),
      'fao' => t('Faroese'),
      'fas' => t('Persian'),
      'fil' => t('Filipino (old - Tagalog)'),
      'fin' => t('Finnish'),
      'fra' => t('French'),
      'frk' => t('German - Fraktur'),
      'frm' => t('French, Middle (ca.1400-1600)'),
      'fry' => t('Western Frisian'),
      'gla' => t('Scottish Gaelic'),
      'gle' => t('Irish'),
      'glg' => t('Galician'),
      'grc' => t('Greek, Ancient (to 1453) (contrib)'),
      'guj' => t('Gujarati'),
      'hat' => t('Haitian; Haitian Creole'),
      'heb' => t('Hebrew'),
      'hin' => t('Hindi'),
      'hrv' => t('Croatian'),
      'hun' => t('Hungarian'),
      'hye' => t('Armenian'),
      'iku' => t('Inuktitut'),
      'ind' => t('Indonesian'),
      'isl' => t('Icelandic'),
      'ita' => t('Italian'),
      'ita_old' => t('Italian - Old'),
      'jav' => t('Javanese'),
      'jpn' => t('Japanese'),
      'kan' => t('Kannada'),
      'kat' => t('Georgian'),
      'kat_old' => t('Georgian - Old'),
      'kaz' => t('Kazakh'),
      'khm' => t('Central Khmer'),
      'kir' => t('Kirghiz; Kyrgyz'),
      'kmr' => t('Kurmanji (Kurdish - Latin Script)'),
      'kor' => t('Korean'),
      'kor_vert' => t('Korean (vertical)'),
      'kur' => t('Kurdish (Arabic Script)'),
      'lao' => t('Lao'),
      'lat' => t('Latin'),
      'lav' => t('Latvian'),
      'lit' => t('Lithuanian'),
      'ltz' => t('Luxembourgish'),
      'mal' => t('Malayalam'),
      'mar' => t('Marathi'),
      'mkd' => t('Macedonian'),
      'mlt' => t('Maltese'),
      'mon' => t('Mongolian'),
      'mri' => t('Maori'),
      'msa' => t('Malay'),
      'mya' => t('Burmese'),
      'nep' => t('Nepali'),
      'nld' => t('Dutch; Flemish'),
      'nor' => t('Norwegian'),
      'oci' => t('Occitan (post 1500)'),
      'ori' => t('Oriya'),
      'osd' => t('Orientation and script detection module'),
      'pan' => t('Panjabi; Punjabi'),
      'pol' => t('Polish'),
      'por' => t('Portuguese'),
      'pus' => t('Pushto; Pashto'),
      'que' => t('Quechua'),
      'ron' => t('Romanian; Moldavian; Moldovan'),
      'rus' => t('Russian'),
      'san' => t('Sanskrit'),
      'sin' => t('Sinhala; Sinhalese'),
      'slk' => t('Slovak'),
      'slk_frak' => t('Slovak - Fraktur (contrib)'),
      'slv' => t('Slovenian'),
      'snd' => t('Sindhi'),
      'spa' => t('Spanish; Castilian'),
      'spa_old' => t('Spanish; Castilian - Old'),
      'sqi' => t('Albanian'),
      'srp' => t('Serbian'),
      'srp_latn' => t('Serbian - Latin'),
      'sun' => t('Sundanese'),
      'swa' => t('Swahili'),
      'swe' => t('Swedish'),
      'syr' => t('Syriac'),
      'tam' => t('Tamil'),
      'tat' => t('Tatar'),
      'tel' => t('Telugu'),
      'tgk' => t('Tajik'),
      'tgl' => t('Tagalog (new - Filipino)'),
      'tha' => t('Thai'),
      'tir' => t('Tigrinya'),
      'ton' => t('Tonga'),
      'tur' => t('Turkish'),
      'uig' => t('Uighur; Uyghur'),
      'ukr' => t('Ukrainian'),
      'urd' => t('Urdu'),
      'uzb' => t('Uzbek'),
      'uzb_cyrl' => t('Uzbek - Cyrilic'),
      'vie' => t('Vietnamese'),
      'yid' => t('Yiddish'),
      'yor' => t('Yoruba'),
    ];
  }

}
